@@ -11,38 +11,34 @@ def func(queue, event, lock, items):
     """ Demo worker function.
 
     This worker function runs in its own process, and uses
-    normal blocking calls to aioprocessing objects, exactly 
+    normal blocking calls to aioprocessing objects, exactly
     the way you would use oridinary multiprocessing objects.
 
     """
     with lock:
         event.set()
         for item in items:
-            time.sleep(1)
+            time.sleep(3)
             queue.put(item+5)
     queue.close()
 
 
-@asyncio.coroutine
-def example(queue, event, lock):
-    l = [1,2]
+async def example(queue, event, lock):
+    l = [1,2,3,4,5]
     p = aioprocessing.AioProcess(target=func, args=(queue, event, lock, l))
     p.start()
     while True:
-        result = yield from queue.coro_get()
+        result = await queue.coro_get()
         if result is None:
             break
         print("Got result {}".format(result))
-    yield from p.coro_join()
-
-
-@asyncio.coroutine
-def example2(queue, event, lock):
-    yield from event.coro_wait()
-    with (yield from lock):
-        yield from queue.coro_put(78)
-        yield from queue.coro_put(None) # Shut down the worker
+    await p.coro_join()
 
+async def example2(queue, event, lock):
+    await event.coro_wait()
+    async with lock:
+        await queue.coro_put(78)
+        await queue.coro_put(None) # Shut down the worker
 
 if __name__ == "__main__":
     loop = asyncio.get_event_loop()
